/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
// Selects all codicon names encapsulated in the `$()` syntax and wraps the
// results with spaces so that screen readers can read the text better.
export function getCodiconAriaLabel(text) {
    if (!text) {
        return '';
    }
    return text.replace(/\$\((.*?)\)/g, (_match, codiconName) => ` ${codiconName} `).trim();
}
/**
 * The Codicon library is a set of default icons that are built-in in VS Code.
 *
 * In the product (outside of base) Codicons should only be used as defaults. In order to have all icons in VS Code
 * themeable, component should define new, UI component specific icons using `iconRegistry.registerIcon`.
 * In that call a Codicon can be named as default.
 */
export class Codicon {
    constructor(id, fontCharacter, description) {
        this.id = id;
        this.fontCharacter = fontCharacter;
        this.description = description;
        Codicon._allCodicons.push(this);
    }
    get classNames() { return 'codicon codicon-' + this.id; }
    // classNamesArray is useful for migrating to ES6 classlist
    get classNamesArray() { return ['codicon', 'codicon-' + this.id]; }
    get cssSelector() { return '.codicon.codicon-' + this.id; }
    /**
     * @returns Returns all default icons covered by the codicon font. Only to be used by the icon registry in platform.
     */
    static getAll() {
        return Codicon._allCodicons;
    }
}
// registry
Codicon._allCodicons = [];
// built-in icons, with image name
Codicon.add = new Codicon('add', '\\ea60');
Codicon.plus = new Codicon('plus', Codicon.add.fontCharacter);
Codicon.gistNew = new Codicon('gist-new', Codicon.add.fontCharacter);
Codicon.repoCreate = new Codicon('repo-create', Codicon.add.fontCharacter);
Codicon.lightbulb = new Codicon('lightbulb', '\\ea61');
Codicon.lightBulb = new Codicon('light-bulb', '\\ea61');
Codicon.repo = new Codicon('repo', '\\ea62');
Codicon.repoDelete = new Codicon('repo-delete', '\\ea62');
Codicon.gistFork = new Codicon('gist-fork', '\\ea63');
Codicon.repoForked = new Codicon('repo-forked', '\\ea63');
Codicon.gitPullRequest = new Codicon('git-pull-request', '\\ea64');
Codicon.gitPullRequestAbandoned = new Codicon('git-pull-request-abandoned', '\\ea64');
Codicon.recordKeys = new Codicon('record-keys', '\\ea65');
Codicon.keyboard = new Codicon('keyboard', '\\ea65');
Codicon.tag = new Codicon('tag', '\\ea66');
Codicon.tagAdd = new Codicon('tag-add', '\\ea66');
Codicon.tagRemove = new Codicon('tag-remove', '\\ea66');
Codicon.person = new Codicon('person', '\\ea67');
Codicon.personFollow = new Codicon('person-follow', '\\ea67');
Codicon.personOutline = new Codicon('person-outline', '\\ea67');
Codicon.personFilled = new Codicon('person-filled', '\\ea67');
Codicon.gitBranch = new Codicon('git-branch', '\\ea68');
Codicon.gitBranchCreate = new Codicon('git-branch-create', '\\ea68');
Codicon.gitBranchDelete = new Codicon('git-branch-delete', '\\ea68');
Codicon.sourceControl = new Codicon('source-control', '\\ea68');
Codicon.mirror = new Codicon('mirror', '\\ea69');
Codicon.mirrorPublic = new Codicon('mirror-public', '\\ea69');
Codicon.star = new Codicon('star', '\\ea6a');
Codicon.starAdd = new Codicon('star-add', '\\ea6a');
Codicon.starDelete = new Codicon('star-delete', '\\ea6a');
Codicon.starEmpty = new Codicon('star-empty', '\\ea6a');
Codicon.comment = new Codicon('comment', '\\ea6b');
Codicon.commentAdd = new Codicon('comment-add', '\\ea6b');
Codicon.alert = new Codicon('alert', '\\ea6c');
Codicon.warning = new Codicon('warning', '\\ea6c');
Codicon.search = new Codicon('search', '\\ea6d');
Codicon.searchSave = new Codicon('search-save', '\\ea6d');
Codicon.logOut = new Codicon('log-out', '\\ea6e');
Codicon.signOut = new Codicon('sign-out', '\\ea6e');
Codicon.logIn = new Codicon('log-in', '\\ea6f');
Codicon.signIn = new Codicon('sign-in', '\\ea6f');
Codicon.eye = new Codicon('eye', '\\ea70');
Codicon.eyeUnwatch = new Codicon('eye-unwatch', '\\ea70');
Codicon.eyeWatch = new Codicon('eye-watch', '\\ea70');
Codicon.circleFilled = new Codicon('circle-filled', '\\ea71');
Codicon.primitiveDot = new Codicon('primitive-dot', Codicon.circleFilled.fontCharacter);
Codicon.closeDirty = new Codicon('close-dirty', Codicon.circleFilled.fontCharacter);
Codicon.debugBreakpoint = new Codicon('debug-breakpoint', Codicon.circleFilled.fontCharacter);
Codicon.debugBreakpointDisabled = new Codicon('debug-breakpoint-disabled', Codicon.circleFilled.fontCharacter);
Codicon.debugHint = new Codicon('debug-hint', Codicon.circleFilled.fontCharacter);
Codicon.primitiveSquare = new Codicon('primitive-square', '\\ea72');
Codicon.edit = new Codicon('edit', '\\ea73');
Codicon.pencil = new Codicon('pencil', '\\ea73');
Codicon.info = new Codicon('info', '\\ea74');
Codicon.issueOpened = new Codicon('issue-opened', '\\ea74');
Codicon.gistPrivate = new Codicon('gist-private', '\\ea75');
Codicon.gitForkPrivate = new Codicon('git-fork-private', '\\ea75');
Codicon.lock = new Codicon('lock', '\\ea75');
Codicon.mirrorPrivate = new Codicon('mirror-private', '\\ea75');
Codicon.close = new Codicon('close', '\\ea76');
Codicon.removeClose = new Codicon('remove-close', '\\ea76');
Codicon.x = new Codicon('x', '\\ea76');
Codicon.repoSync = new Codicon('repo-sync', '\\ea77');
Codicon.sync = new Codicon('sync', '\\ea77');
Codicon.clone = new Codicon('clone', '\\ea78');
Codicon.desktopDownload = new Codicon('desktop-download', '\\ea78');
Codicon.beaker = new Codicon('beaker', '\\ea79');
Codicon.microscope = new Codicon('microscope', '\\ea79');
Codicon.vm = new Codicon('vm', '\\ea7a');
Codicon.deviceDesktop = new Codicon('device-desktop', '\\ea7a');
Codicon.file = new Codicon('file', '\\ea7b');
Codicon.fileText = new Codicon('file-text', '\\ea7b');
Codicon.more = new Codicon('more', '\\ea7c');
Codicon.ellipsis = new Codicon('ellipsis', '\\ea7c');
Codicon.kebabHorizontal = new Codicon('kebab-horizontal', '\\ea7c');
Codicon.mailReply = new Codicon('mail-reply', '\\ea7d');
Codicon.reply = new Codicon('reply', '\\ea7d');
Codicon.organization = new Codicon('organization', '\\ea7e');
Codicon.organizationFilled = new Codicon('organization-filled', '\\ea7e');
Codicon.organizationOutline = new Codicon('organization-outline', '\\ea7e');
Codicon.newFile = new Codicon('new-file', '\\ea7f');
Codicon.fileAdd = new Codicon('file-add', '\\ea7f');
Codicon.newFolder = new Codicon('new-folder', '\\ea80');
Codicon.fileDirectoryCreate = new Codicon('file-directory-create', '\\ea80');
Codicon.trash = new Codicon('trash', '\\ea81');
Codicon.trashcan = new Codicon('trashcan', '\\ea81');
Codicon.history = new Codicon('history', '\\ea82');
Codicon.clock = new Codicon('clock', '\\ea82');
Codicon.folder = new Codicon('folder', '\\ea83');
Codicon.fileDirectory = new Codicon('file-directory', '\\ea83');
Codicon.symbolFolder = new Codicon('symbol-folder', '\\ea83');
Codicon.logoGithub = new Codicon('logo-github', '\\ea84');
Codicon.markGithub = new Codicon('mark-github', '\\ea84');
Codicon.github = new Codicon('github', '\\ea84');
Codicon.terminal = new Codicon('terminal', '\\ea85');
Codicon.console = new Codicon('console', '\\ea85');
Codicon.repl = new Codicon('repl', '\\ea85');
Codicon.zap = new Codicon('zap', '\\ea86');
Codicon.symbolEvent = new Codicon('symbol-event', '\\ea86');
Codicon.error = new Codicon('error', '\\ea87');
Codicon.stop = new Codicon('stop', '\\ea87');
Codicon.variable = new Codicon('variable', '\\ea88');
Codicon.symbolVariable = new Codicon('symbol-variable', '\\ea88');
Codicon.array = new Codicon('array', '\\ea8a');
Codicon.symbolArray = new Codicon('symbol-array', '\\ea8a');
Codicon.symbolModule = new Codicon('symbol-module', '\\ea8b');
Codicon.symbolPackage = new Codicon('symbol-package', '\\ea8b');
Codicon.symbolNamespace = new Codicon('symbol-namespace', '\\ea8b');
Codicon.symbolObject = new Codicon('symbol-object', '\\ea8b');
Codicon.symbolMethod = new Codicon('symbol-method', '\\ea8c');
Codicon.symbolFunction = new Codicon('symbol-function', '\\ea8c');
Codicon.symbolConstructor = new Codicon('symbol-constructor', '\\ea8c');
Codicon.symbolBoolean = new Codicon('symbol-boolean', '\\ea8f');
Codicon.symbolNull = new Codicon('symbol-null', '\\ea8f');
Codicon.symbolNumeric = new Codicon('symbol-numeric', '\\ea90');
Codicon.symbolNumber = new Codicon('symbol-number', '\\ea90');
Codicon.symbolStructure = new Codicon('symbol-structure', '\\ea91');
Codicon.symbolStruct = new Codicon('symbol-struct', '\\ea91');
Codicon.symbolParameter = new Codicon('symbol-parameter', '\\ea92');
Codicon.symbolTypeParameter = new Codicon('symbol-type-parameter', '\\ea92');
Codicon.symbolKey = new Codicon('symbol-key', '\\ea93');
Codicon.symbolText = new Codicon('symbol-text', '\\ea93');
Codicon.symbolReference = new Codicon('symbol-reference', '\\ea94');
Codicon.goToFile = new Codicon('go-to-file', '\\ea94');
Codicon.symbolEnum = new Codicon('symbol-enum', '\\ea95');
Codicon.symbolValue = new Codicon('symbol-value', '\\ea95');
Codicon.symbolRuler = new Codicon('symbol-ruler', '\\ea96');
Codicon.symbolUnit = new Codicon('symbol-unit', '\\ea96');
Codicon.activateBreakpoints = new Codicon('activate-breakpoints', '\\ea97');
Codicon.archive = new Codicon('archive', '\\ea98');
Codicon.arrowBoth = new Codicon('arrow-both', '\\ea99');
Codicon.arrowDown = new Codicon('arrow-down', '\\ea9a');
Codicon.arrowLeft = new Codicon('arrow-left', '\\ea9b');
Codicon.arrowRight = new Codicon('arrow-right', '\\ea9c');
Codicon.arrowSmallDown = new Codicon('arrow-small-down', '\\ea9d');
Codicon.arrowSmallLeft = new Codicon('arrow-small-left', '\\ea9e');
Codicon.arrowSmallRight = new Codicon('arrow-small-right', '\\ea9f');
Codicon.arrowSmallUp = new Codicon('arrow-small-up', '\\eaa0');
Codicon.arrowUp = new Codicon('arrow-up', '\\eaa1');
Codicon.bell = new Codicon('bell', '\\eaa2');
Codicon.bold = new Codicon('bold', '\\eaa3');
Codicon.book = new Codicon('book', '\\eaa4');
Codicon.bookmark = new Codicon('bookmark', '\\eaa5');
Codicon.debugBreakpointConditionalUnverified = new Codicon('debug-breakpoint-conditional-unverified', '\\eaa6');
Codicon.debugBreakpointConditional = new Codicon('debug-breakpoint-conditional', '\\eaa7');
Codicon.debugBreakpointConditionalDisabled = new Codicon('debug-breakpoint-conditional-disabled', '\\eaa7');
Codicon.debugBreakpointDataUnverified = new Codicon('debug-breakpoint-data-unverified', '\\eaa8');
Codicon.debugBreakpointData = new Codicon('debug-breakpoint-data', '\\eaa9');
Codicon.debugBreakpointDataDisabled = new Codicon('debug-breakpoint-data-disabled', '\\eaa9');
Codicon.debugBreakpointLogUnverified = new Codicon('debug-breakpoint-log-unverified', '\\eaaa');
Codicon.debugBreakpointLog = new Codicon('debug-breakpoint-log', '\\eaab');
Codicon.debugBreakpointLogDisabled = new Codicon('debug-breakpoint-log-disabled', '\\eaab');
Codicon.briefcase = new Codicon('briefcase', '\\eaac');
Codicon.broadcast = new Codicon('broadcast', '\\eaad');
Codicon.browser = new Codicon('browser', '\\eaae');
Codicon.bug = new Codicon('bug', '\\eaaf');
Codicon.calendar = new Codicon('calendar', '\\eab0');
Codicon.caseSensitive = new Codicon('case-sensitive', '\\eab1');
Codicon.check = new Codicon('check', '\\eab2');
Codicon.checklist = new Codicon('checklist', '\\eab3');
Codicon.chevronDown = new Codicon('chevron-down', '\\eab4');
Codicon.dropDownButton = new Codicon('drop-down-button', Codicon.chevronDown.fontCharacter);
Codicon.chevronLeft = new Codicon('chevron-left', '\\eab5');
Codicon.chevronRight = new Codicon('chevron-right', '\\eab6');
Codicon.chevronUp = new Codicon('chevron-up', '\\eab7');
Codicon.chromeClose = new Codicon('chrome-close', '\\eab8');
Codicon.chromeMaximize = new Codicon('chrome-maximize', '\\eab9');
Codicon.chromeMinimize = new Codicon('chrome-minimize', '\\eaba');
Codicon.chromeRestore = new Codicon('chrome-restore', '\\eabb');
Codicon.circle = new Codicon('circle', '\\eabc');
Codicon.circleOutline = new Codicon('circle-outline', Codicon.circle.fontCharacter);
Codicon.debugBreakpointUnverified = new Codicon('debug-breakpoint-unverified', Codicon.circle.fontCharacter);
Codicon.circleSlash = new Codicon('circle-slash', '\\eabd');
Codicon.circuitBoard = new Codicon('circuit-board', '\\eabe');
Codicon.clearAll = new Codicon('clear-all', '\\eabf');
Codicon.clippy = new Codicon('clippy', '\\eac0');
Codicon.closeAll = new Codicon('close-all', '\\eac1');
Codicon.cloudDownload = new Codicon('cloud-download', '\\eac2');
Codicon.cloudUpload = new Codicon('cloud-upload', '\\eac3');
Codicon.code = new Codicon('code', '\\eac4');
Codicon.collapseAll = new Codicon('collapse-all', '\\eac5');
Codicon.colorMode = new Codicon('color-mode', '\\eac6');
Codicon.commentDiscussion = new Codicon('comment-discussion', '\\eac7');
Codicon.compareChanges = new Codicon('compare-changes', '\\eafd');
Codicon.creditCard = new Codicon('credit-card', '\\eac9');
Codicon.dash = new Codicon('dash', '\\eacc');
Codicon.dashboard = new Codicon('dashboard', '\\eacd');
Codicon.database = new Codicon('database', '\\eace');
Codicon.debugContinue = new Codicon('debug-continue', '\\eacf');
Codicon.debugDisconnect = new Codicon('debug-disconnect', '\\ead0');
Codicon.debugPause = new Codicon('debug-pause', '\\ead1');
Codicon.debugRestart = new Codicon('debug-restart', '\\ead2');
Codicon.debugStart = new Codicon('debug-start', '\\ead3');
Codicon.debugStepInto = new Codicon('debug-step-into', '\\ead4');
Codicon.debugStepOut = new Codicon('debug-step-out', '\\ead5');
Codicon.debugStepOver = new Codicon('debug-step-over', '\\ead6');
Codicon.debugStop = new Codicon('debug-stop', '\\ead7');
Codicon.debug = new Codicon('debug', '\\ead8');
Codicon.deviceCameraVideo = new Codicon('device-camera-video', '\\ead9');
Codicon.deviceCamera = new Codicon('device-camera', '\\eada');
Codicon.deviceMobile = new Codicon('device-mobile', '\\eadb');
Codicon.diffAdded = new Codicon('diff-added', '\\eadc');
Codicon.diffIgnored = new Codicon('diff-ignored', '\\eadd');
Codicon.diffModified = new Codicon('diff-modified', '\\eade');
Codicon.diffRemoved = new Codicon('diff-removed', '\\eadf');
Codicon.diffRenamed = new Codicon('diff-renamed', '\\eae0');
Codicon.diff = new Codicon('diff', '\\eae1');
Codicon.discard = new Codicon('discard', '\\eae2');
Codicon.editorLayout = new Codicon('editor-layout', '\\eae3');
Codicon.emptyWindow = new Codicon('empty-window', '\\eae4');
Codicon.exclude = new Codicon('exclude', '\\eae5');
Codicon.extensions = new Codicon('extensions', '\\eae6');
Codicon.eyeClosed = new Codicon('eye-closed', '\\eae7');
Codicon.fileBinary = new Codicon('file-binary', '\\eae8');
Codicon.fileCode = new Codicon('file-code', '\\eae9');
Codicon.fileMedia = new Codicon('file-media', '\\eaea');
Codicon.filePdf = new Codicon('file-pdf', '\\eaeb');
Codicon.fileSubmodule = new Codicon('file-submodule', '\\eaec');
Codicon.fileSymlinkDirectory = new Codicon('file-symlink-directory', '\\eaed');
Codicon.fileSymlinkFile = new Codicon('file-symlink-file', '\\eaee');
Codicon.fileZip = new Codicon('file-zip', '\\eaef');
Codicon.files = new Codicon('files', '\\eaf0');
Codicon.filter = new Codicon('filter', '\\eaf1');
Codicon.flame = new Codicon('flame', '\\eaf2');
Codicon.foldDown = new Codicon('fold-down', '\\eaf3');
Codicon.foldUp = new Codicon('fold-up', '\\eaf4');
Codicon.fold = new Codicon('fold', '\\eaf5');
Codicon.folderActive = new Codicon('folder-active', '\\eaf6');
Codicon.folderOpened = new Codicon('folder-opened', '\\eaf7');
Codicon.gear = new Codicon('gear', '\\eaf8');
Codicon.gift = new Codicon('gift', '\\eaf9');
Codicon.gistSecret = new Codicon('gist-secret', '\\eafa');
Codicon.gist = new Codicon('gist', '\\eafb');
Codicon.gitCommit = new Codicon('git-commit', '\\eafc');
Codicon.gitCompare = new Codicon('git-compare', '\\eafd');
Codicon.gitMerge = new Codicon('git-merge', '\\eafe');
Codicon.githubAction = new Codicon('github-action', '\\eaff');
Codicon.githubAlt = new Codicon('github-alt', '\\eb00');
Codicon.globe = new Codicon('globe', '\\eb01');
Codicon.grabber = new Codicon('grabber', '\\eb02');
Codicon.graph = new Codicon('graph', '\\eb03');
Codicon.gripper = new Codicon('gripper', '\\eb04');
Codicon.heart = new Codicon('heart', '\\eb05');
Codicon.home = new Codicon('home', '\\eb06');
Codicon.horizontalRule = new Codicon('horizontal-rule', '\\eb07');
Codicon.hubot = new Codicon('hubot', '\\eb08');
Codicon.inbox = new Codicon('inbox', '\\eb09');
Codicon.issueClosed = new Codicon('issue-closed', '\\eba4');
Codicon.issueReopened = new Codicon('issue-reopened', '\\eb0b');
Codicon.issues = new Codicon('issues', '\\eb0c');
Codicon.italic = new Codicon('italic', '\\eb0d');
Codicon.jersey = new Codicon('jersey', '\\eb0e');
Codicon.json = new Codicon('json', '\\eb0f');
Codicon.kebabVertical = new Codicon('kebab-vertical', '\\eb10');
Codicon.key = new Codicon('key', '\\eb11');
Codicon.law = new Codicon('law', '\\eb12');
Codicon.lightbulbAutofix = new Codicon('lightbulb-autofix', '\\eb13');
Codicon.linkExternal = new Codicon('link-external', '\\eb14');
Codicon.link = new Codicon('link', '\\eb15');
Codicon.listOrdered = new Codicon('list-ordered', '\\eb16');
Codicon.listUnordered = new Codicon('list-unordered', '\\eb17');
Codicon.liveShare = new Codicon('live-share', '\\eb18');
Codicon.loading = new Codicon('loading', '\\eb19');
Codicon.location = new Codicon('location', '\\eb1a');
Codicon.mailRead = new Codicon('mail-read', '\\eb1b');
Codicon.mail = new Codicon('mail', '\\eb1c');
Codicon.markdown = new Codicon('markdown', '\\eb1d');
Codicon.megaphone = new Codicon('megaphone', '\\eb1e');
Codicon.mention = new Codicon('mention', '\\eb1f');
Codicon.milestone = new Codicon('milestone', '\\eb20');
Codicon.mortarBoard = new Codicon('mortar-board', '\\eb21');
Codicon.move = new Codicon('move', '\\eb22');
Codicon.multipleWindows = new Codicon('multiple-windows', '\\eb23');
Codicon.mute = new Codicon('mute', '\\eb24');
Codicon.noNewline = new Codicon('no-newline', '\\eb25');
Codicon.note = new Codicon('note', '\\eb26');
Codicon.octoface = new Codicon('octoface', '\\eb27');
Codicon.openPreview = new Codicon('open-preview', '\\eb28');
Codicon.package_ = new Codicon('package', '\\eb29');
Codicon.paintcan = new Codicon('paintcan', '\\eb2a');
Codicon.pin = new Codicon('pin', '\\eb2b');
Codicon.play = new Codicon('play', '\\eb2c');
Codicon.run = new Codicon('run', '\\eb2c');
Codicon.plug = new Codicon('plug', '\\eb2d');
Codicon.preserveCase = new Codicon('preserve-case', '\\eb2e');
Codicon.preview = new Codicon('preview', '\\eb2f');
Codicon.project = new Codicon('project', '\\eb30');
Codicon.pulse = new Codicon('pulse', '\\eb31');
Codicon.question = new Codicon('question', '\\eb32');
Codicon.quote = new Codicon('quote', '\\eb33');
Codicon.radioTower = new Codicon('radio-tower', '\\eb34');
Codicon.reactions = new Codicon('reactions', '\\eb35');
Codicon.references = new Codicon('references', '\\eb36');
Codicon.refresh = new Codicon('refresh', '\\eb37');
Codicon.regex = new Codicon('regex', '\\eb38');
Codicon.remoteExplorer = new Codicon('remote-explorer', '\\eb39');
Codicon.remote = new Codicon('remote', '\\eb3a');
Codicon.remove = new Codicon('remove', '\\eb3b');
Codicon.replaceAll = new Codicon('replace-all', '\\eb3c');
Codicon.replace = new Codicon('replace', '\\eb3d');
Codicon.repoClone = new Codicon('repo-clone', '\\eb3e');
Codicon.repoForcePush = new Codicon('repo-force-push', '\\eb3f');
Codicon.repoPull = new Codicon('repo-pull', '\\eb40');
Codicon.repoPush = new Codicon('repo-push', '\\eb41');
Codicon.report = new Codicon('report', '\\eb42');
Codicon.requestChanges = new Codicon('request-changes', '\\eb43');
Codicon.rocket = new Codicon('rocket', '\\eb44');
Codicon.rootFolderOpened = new Codicon('root-folder-opened', '\\eb45');
Codicon.rootFolder = new Codicon('root-folder', '\\eb46');
Codicon.rss = new Codicon('rss', '\\eb47');
Codicon.ruby = new Codicon('ruby', '\\eb48');
Codicon.saveAll = new Codicon('save-all', '\\eb49');
Codicon.saveAs = new Codicon('save-as', '\\eb4a');
Codicon.save = new Codicon('save', '\\eb4b');
Codicon.screenFull = new Codicon('screen-full', '\\eb4c');
Codicon.screenNormal = new Codicon('screen-normal', '\\eb4d');
Codicon.searchStop = new Codicon('search-stop', '\\eb4e');
Codicon.server = new Codicon('server', '\\eb50');
Codicon.settingsGear = new Codicon('settings-gear', '\\eb51');
Codicon.settings = new Codicon('settings', '\\eb52');
Codicon.shield = new Codicon('shield', '\\eb53');
Codicon.smiley = new Codicon('smiley', '\\eb54');
Codicon.sortPrecedence = new Codicon('sort-precedence', '\\eb55');
Codicon.splitHorizontal = new Codicon('split-horizontal', '\\eb56');
Codicon.splitVertical = new Codicon('split-vertical', '\\eb57');
Codicon.squirrel = new Codicon('squirrel', '\\eb58');
Codicon.starFull = new Codicon('star-full', '\\eb59');
Codicon.starHalf = new Codicon('star-half', '\\eb5a');
Codicon.symbolClass = new Codicon('symbol-class', '\\eb5b');
Codicon.symbolColor = new Codicon('symbol-color', '\\eb5c');
Codicon.symbolCustomColor = new Codicon('symbol-customcolor', '\\eb5c');
Codicon.symbolConstant = new Codicon('symbol-constant', '\\eb5d');
Codicon.symbolEnumMember = new Codicon('symbol-enum-member', '\\eb5e');
Codicon.symbolField = new Codicon('symbol-field', '\\eb5f');
Codicon.symbolFile = new Codicon('symbol-file', '\\eb60');
Codicon.symbolInterface = new Codicon('symbol-interface', '\\eb61');
Codicon.symbolKeyword = new Codicon('symbol-keyword', '\\eb62');
Codicon.symbolMisc = new Codicon('symbol-misc', '\\eb63');
Codicon.symbolOperator = new Codicon('symbol-operator', '\\eb64');
Codicon.symbolProperty = new Codicon('symbol-property', '\\eb65');
Codicon.wrench = new Codicon('wrench', '\\eb65');
Codicon.wrenchSubaction = new Codicon('wrench-subaction', '\\eb65');
Codicon.symbolSnippet = new Codicon('symbol-snippet', '\\eb66');
Codicon.tasklist = new Codicon('tasklist', '\\eb67');
Codicon.telescope = new Codicon('telescope', '\\eb68');
Codicon.textSize = new Codicon('text-size', '\\eb69');
Codicon.threeBars = new Codicon('three-bars', '\\eb6a');
Codicon.thumbsdown = new Codicon('thumbsdown', '\\eb6b');
Codicon.thumbsup = new Codicon('thumbsup', '\\eb6c');
Codicon.tools = new Codicon('tools', '\\eb6d');
Codicon.triangleDown = new Codicon('triangle-down', '\\eb6e');
Codicon.triangleLeft = new Codicon('triangle-left', '\\eb6f');
Codicon.triangleRight = new Codicon('triangle-right', '\\eb70');
Codicon.triangleUp = new Codicon('triangle-up', '\\eb71');
Codicon.twitter = new Codicon('twitter', '\\eb72');
Codicon.unfold = new Codicon('unfold', '\\eb73');
Codicon.unlock = new Codicon('unlock', '\\eb74');
Codicon.unmute = new Codicon('unmute', '\\eb75');
Codicon.unverified = new Codicon('unverified', '\\eb76');
Codicon.verified = new Codicon('verified', '\\eb77');
Codicon.versions = new Codicon('versions', '\\eb78');
Codicon.vmActive = new Codicon('vm-active', '\\eb79');
Codicon.vmOutline = new Codicon('vm-outline', '\\eb7a');
Codicon.vmRunning = new Codicon('vm-running', '\\eb7b');
Codicon.watch = new Codicon('watch', '\\eb7c');
Codicon.whitespace = new Codicon('whitespace', '\\eb7d');
Codicon.wholeWord = new Codicon('whole-word', '\\eb7e');
Codicon.window = new Codicon('window', '\\eb7f');
Codicon.wordWrap = new Codicon('word-wrap', '\\eb80');
Codicon.zoomIn = new Codicon('zoom-in', '\\eb81');
Codicon.zoomOut = new Codicon('zoom-out', '\\eb82');
Codicon.listFilter = new Codicon('list-filter', '\\eb83');
Codicon.listFlat = new Codicon('list-flat', '\\eb84');
Codicon.listSelection = new Codicon('list-selection', '\\eb85');
Codicon.selection = new Codicon('selection', '\\eb85');
Codicon.listTree = new Codicon('list-tree', '\\eb86');
Codicon.debugBreakpointFunctionUnverified = new Codicon('debug-breakpoint-function-unverified', '\\eb87');
Codicon.debugBreakpointFunction = new Codicon('debug-breakpoint-function', '\\eb88');
Codicon.debugBreakpointFunctionDisabled = new Codicon('debug-breakpoint-function-disabled', '\\eb88');
Codicon.debugStackframeActive = new Codicon('debug-stackframe-active', '\\eb89');
Codicon.circleSmallFilled = new Codicon('circle-small-filled', '\\eb8a');
Codicon.debugStackframeDot = new Codicon('debug-stackframe-dot', Codicon.circleSmallFilled.fontCharacter);
Codicon.debugStackframe = new Codicon('debug-stackframe', '\\eb8b');
Codicon.debugStackframeFocused = new Codicon('debug-stackframe-focused', '\\eb8b');
Codicon.debugBreakpointUnsupported = new Codicon('debug-breakpoint-unsupported', '\\eb8c');
Codicon.symbolString = new Codicon('symbol-string', '\\eb8d');
Codicon.debugReverseContinue = new Codicon('debug-reverse-continue', '\\eb8e');
Codicon.debugStepBack = new Codicon('debug-step-back', '\\eb8f');
Codicon.debugRestartFrame = new Codicon('debug-restart-frame', '\\eb90');
Codicon.callIncoming = new Codicon('call-incoming', '\\eb92');
Codicon.callOutgoing = new Codicon('call-outgoing', '\\eb93');
Codicon.menu = new Codicon('menu', '\\eb94');
Codicon.expandAll = new Codicon('expand-all', '\\eb95');
Codicon.feedback = new Codicon('feedback', '\\eb96');
Codicon.groupByRefType = new Codicon('group-by-ref-type', '\\eb97');
Codicon.ungroupByRefType = new Codicon('ungroup-by-ref-type', '\\eb98');
Codicon.account = new Codicon('account', '\\eb99');
Codicon.bellDot = new Codicon('bell-dot', '\\eb9a');
Codicon.debugConsole = new Codicon('debug-console', '\\eb9b');
Codicon.library = new Codicon('library', '\\eb9c');
Codicon.output = new Codicon('output', '\\eb9d');
Codicon.runAll = new Codicon('run-all', '\\eb9e');
Codicon.syncIgnored = new Codicon('sync-ignored', '\\eb9f');
Codicon.pinned = new Codicon('pinned', '\\eba0');
Codicon.githubInverted = new Codicon('github-inverted', '\\eba1');
Codicon.debugAlt = new Codicon('debug-alt', '\\eb91');
Codicon.serverProcess = new Codicon('server-process', '\\eba2');
Codicon.serverEnvironment = new Codicon('server-environment', '\\eba3');
Codicon.pass = new Codicon('pass', '\\eba4');
Codicon.stopCircle = new Codicon('stop-circle', '\\eba5');
Codicon.playCircle = new Codicon('play-circle', '\\eba6');
Codicon.record = new Codicon('record', '\\eba7');
Codicon.debugAltSmall = new Codicon('debug-alt-small', '\\eba8');
Codicon.vmConnect = new Codicon('vm-connect', '\\eba9');
Codicon.cloud = new Codicon('cloud', '\\ebaa');
Codicon.merge = new Codicon('merge', '\\ebab');
Codicon.exportIcon = new Codicon('export', '\\ebac');
Codicon.graphLeft = new Codicon('graph-left', '\\ebad');
Codicon.magnet = new Codicon('magnet', '\\ebae');
Codicon.notebook = new Codicon('notebook', '\\ebaf');
Codicon.redo = new Codicon('redo', '\\ebb0');
Codicon.checkAll = new Codicon('check-all', '\\ebb1');
Codicon.pinnedDirty = new Codicon('pinned-dirty', '\\ebb2');
Codicon.passFilled = new Codicon('pass-filled', '\\ebb3');
Codicon.circleLargeFilled = new Codicon('circle-large-filled', '\\ebb4');
Codicon.circleLarge = new Codicon('circle-large', '\\ebb5');
Codicon.circleLargeOutline = new Codicon('circle-large-outline', Codicon.circleLarge.fontCharacter);
Codicon.combine = new Codicon('combine', '\\ebb6');
Codicon.gather = new Codicon('gather', '\\ebb6');
Codicon.table = new Codicon('table', '\\ebb7');
Codicon.variableGroup = new Codicon('variable-group', '\\ebb8');
Codicon.typeHierarchy = new Codicon('type-hierarchy', '\\ebb9');
Codicon.typeHierarchySub = new Codicon('type-hierarchy-sub', '\\ebba');
Codicon.typeHierarchySuper = new Codicon('type-hierarchy-super', '\\ebbb');
Codicon.gitPullRequestCreate = new Codicon('git-pull-request-create', '\\ebbc');
Codicon.runAbove = new Codicon('run-above', '\\ebbd');
Codicon.runBelow = new Codicon('run-below', '\\ebbe');
Codicon.notebookTemplate = new Codicon('notebook-template', '\\ebbf');
Codicon.debugRerun = new Codicon('debug-rerun', '\\ebc0');
Codicon.workspaceTrusted = new Codicon('workspace-trusted', '\\ebc1');
Codicon.workspaceUntrusted = new Codicon('workspace-untrusted', '\\ebc2');
Codicon.workspaceUnspecified = new Codicon('workspace-unspecified', '\\ebc3');
Codicon.terminalCmd = new Codicon('terminal-cmd', '\\ebc4');
Codicon.terminalDebian = new Codicon('terminal-debian', '\\ebc5');
Codicon.terminalLinux = new Codicon('terminal-linux', '\\ebc6');
Codicon.terminalPowershell = new Codicon('terminal-powershell', '\\ebc7');
Codicon.terminalTmux = new Codicon('terminal-tmux', '\\ebc8');
Codicon.terminalUbuntu = new Codicon('terminal-ubuntu', '\\ebc9');
Codicon.terminalBash = new Codicon('terminal-bash', '\\ebca');
Codicon.arrowSwap = new Codicon('arrow-swap', '\\ebcb');
Codicon.copy = new Codicon('copy', '\\ebcc');
Codicon.personAdd = new Codicon('person-add', '\\ebcd');
Codicon.filterFilled = new Codicon('filter-filled', '\\ebce');
Codicon.wand = new Codicon('wand', '\\ebcf');
Codicon.debugLineByLine = new Codicon('debug-line-by-line', '\\ebd0');
Codicon.inspect = new Codicon('inspect', '\\ebd1');
Codicon.layers = new Codicon('layers', '\\ebd2');
Codicon.layersDot = new Codicon('layers-dot', '\\ebd3');
Codicon.layersActive = new Codicon('layers-active', '\\ebd4');
Codicon.compass = new Codicon('compass', '\\ebd5');
Codicon.compassDot = new Codicon('compass-dot', '\\ebd6');
Codicon.compassActive = new Codicon('compass-active', '\\ebd7');
Codicon.azure = new Codicon('azure', '\\ebd8');
Codicon.issueDraft = new Codicon('issue-draft', '\\ebd9');
Codicon.gitPullRequestClosed = new Codicon('git-pull-request-closed', '\\ebda');
Codicon.gitPullRequestDraft = new Codicon('git-pull-request-draft', '\\ebdb');
Codicon.debugAll = new Codicon('debug-all', '\\ebdc');
Codicon.debugCoverage = new Codicon('debug-coverage', '\\ebdd');
Codicon.runErrors = new Codicon('run-errors', '\\ebde');
Codicon.folderLibrary = new Codicon('folder-library', '\\ebdf');
Codicon.debugContinueSmall = new Codicon('debug-continue-small', '\\ebe0');
Codicon.beakerStop = new Codicon('beaker-stop', '\\ebe1');
Codicon.graphLine = new Codicon('graph-line', '\\ebe2');
Codicon.graphScatter = new Codicon('graph-scatter', '\\ebe3');
Codicon.pieChart = new Codicon('pie-chart', '\\ebe4');
Codicon.bracket = new Codicon('bracket', Codicon.json.fontCharacter);
Codicon.bracketDot = new Codicon('bracket-dot', '\\ebe5');
Codicon.bracketError = new Codicon('bracket-error', '\\ebe6');
Codicon.lockSmall = new Codicon('lock-small', '\\ebe7');
Codicon.azureDevops = new Codicon('azure-devops', '\\ebe8');
Codicon.verifiedFilled = new Codicon('verified-filled', '\\ebe9');
Codicon.newLine = new Codicon('newline', '\\ebea');
Codicon.layout = new Codicon('layout', '\\ebeb');
Codicon.layoutActivitybarLeft = new Codicon('layout-activitybar-left', '\\ebec');
Codicon.layoutActivitybarRight = new Codicon('layout-activitybar-right', '\\ebed');
Codicon.layoutPanelLeft = new Codicon('layout-panel-left', '\\ebee');
Codicon.layoutPanelCenter = new Codicon('layout-panel-center', '\\ebef');
Codicon.layoutPanelJustify = new Codicon('layout-panel-justify', '\\ebf0');
Codicon.layoutPanelRight = new Codicon('layout-panel-right', '\\ebf1');
Codicon.layoutPanel = new Codicon('layout-panel', '\\ebf2');
Codicon.layoutSidebarLeft = new Codicon('layout-sidebar-left', '\\ebf3');
Codicon.layoutSidebarRight = new Codicon('layout-sidebar-right', '\\ebf4');
Codicon.layoutStatusbar = new Codicon('layout-statusbar', '\\ebf5');
Codicon.layoutMenubar = new Codicon('layout-menubar', '\\ebf6');
Codicon.layoutCentered = new Codicon('layout-centered', '\\ebf7');
Codicon.layoutSidebarRightOff = new Codicon('layout-sidebar-right-off', '\\ec00');
Codicon.layoutPanelOff = new Codicon('layout-panel-off', '\\ec01');
Codicon.layoutSidebarLeftOff = new Codicon('layout-sidebar-left-off', '\\ec02');
Codicon.target = new Codicon('target', '\\ebf8');
Codicon.indent = new Codicon('indent', '\\ebf9');
Codicon.recordSmall = new Codicon('record-small', '\\ebfa');
Codicon.errorSmall = new Codicon('error-small', '\\ebfb');
Codicon.arrowCircleDown = new Codicon('arrow-circle-down', '\\ebfc');
Codicon.arrowCircleLeft = new Codicon('arrow-circle-left', '\\ebfd');
Codicon.arrowCircleRight = new Codicon('arrow-circle-right', '\\ebfe');
Codicon.arrowCircleUp = new Codicon('arrow-circle-up', '\\ebff');
Codicon.heartFilled = new Codicon('heart-filled', '\\ec04');
Codicon.map = new Codicon('map', '\\ec05');
Codicon.mapFilled = new Codicon('map-filled', '\\ec06');
Codicon.circleSmall = new Codicon('circle-small', '\\ec07');
Codicon.bellSlash = new Codicon('bell-slash', '\\ec08');
Codicon.bellSlashDot = new Codicon('bell-slash-dot', '\\ec09');
Codicon.commentUnresolved = new Codicon('comment-unresolved', '\\ec0a');
Codicon.gitPullRequestGoToChanges = new Codicon('git-pull-request-go-to-changes', '\\ec0b');
Codicon.gitPullRequestNewChanges = new Codicon('git-pull-request-new-changes', '\\ec0c');
Codicon.searchFuzzy = new Codicon('search-fuzzy', '\\ec0d');
Codicon.commentDraft = new Codicon('comment-draft', '\\ec0e');
// derived icons, that could become separate icons
Codicon.dialogError = new Codicon('dialog-error', Codicon.error.fontCharacter);
Codicon.dialogWarning = new Codicon('dialog-warning', Codicon.warning.fontCharacter);
Codicon.dialogInfo = new Codicon('dialog-info', Codicon.info.fontCharacter);
Codicon.dialogClose = new Codicon('dialog-close', Codicon.close.fontCharacter);
Codicon.treeItemExpanded = new Codicon('tree-item-expanded', Codicon.chevronDown.fontCharacter); // collapsed is done with rotation
Codicon.treeFilterOnTypeOn = new Codicon('tree-filter-on-type-on', Codicon.listFilter.fontCharacter);
Codicon.treeFilterOnTypeOff = new Codicon('tree-filter-on-type-off', Codicon.listSelection.fontCharacter);
Codicon.treeFilterClear = new Codicon('tree-filter-clear', Codicon.close.fontCharacter);
Codicon.treeItemLoading = new Codicon('tree-item-loading', Codicon.loading.fontCharacter);
Codicon.menuSelection = new Codicon('menu-selection', Codicon.check.fontCharacter);
Codicon.menuSubmenu = new Codicon('menu-submenu', Codicon.chevronRight.fontCharacter);
Codicon.menuBarMore = new Codicon('menubar-more', Codicon.more.fontCharacter);
Codicon.scrollbarButtonLeft = new Codicon('scrollbar-button-left', Codicon.triangleLeft.fontCharacter);
Codicon.scrollbarButtonRight = new Codicon('scrollbar-button-right', Codicon.triangleRight.fontCharacter);
Codicon.scrollbarButtonUp = new Codicon('scrollbar-button-up', Codicon.triangleUp.fontCharacter);
Codicon.scrollbarButtonDown = new Codicon('scrollbar-button-down', Codicon.triangleDown.fontCharacter);
Codicon.toolBarMore = new Codicon('toolbar-more', Codicon.more.fontCharacter);
Codicon.quickInputBack = new Codicon('quick-input-back', Codicon.arrowLeft.fontCharacter);
export var CSSIcon;
(function (CSSIcon) {
    CSSIcon.iconNameSegment = '[A-Za-z0-9]+';
    CSSIcon.iconNameExpression = '[A-Za-z0-9-]+';
    CSSIcon.iconModifierExpression = '~[A-Za-z]+';
    CSSIcon.iconNameCharacter = '[A-Za-z0-9~-]';
    const cssIconIdRegex = new RegExp(`^(${CSSIcon.iconNameExpression})(${CSSIcon.iconModifierExpression})?$`);
    function asClassNameArray(icon) {
        if (icon instanceof Codicon) {
            return ['codicon', 'codicon-' + icon.id];
        }
        const match = cssIconIdRegex.exec(icon.id);
        if (!match) {
            return asClassNameArray(Codicon.error);
        }
        const [, id, modifier] = match;
        const classNames = ['codicon', 'codicon-' + id];
        if (modifier) {
            classNames.push('codicon-modifier-' + modifier.substring(1));
        }
        return classNames;
    }
    CSSIcon.asClassNameArray = asClassNameArray;
    function asClassName(icon) {
        return asClassNameArray(icon).join(' ');
    }
    CSSIcon.asClassName = asClassName;
    function asCSSSelector(icon) {
        return '.' + asClassNameArray(icon).join('.');
    }
    CSSIcon.asCSSSelector = asCSSSelector;
})(CSSIcon || (CSSIcon = {}));
